@@ -8,7 +8,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moo;
 use MIDI::Simple;
@@ -64,6 +64,7 @@ has score => ( is => 'ro' );
 
 has file => ( is => 'ro', default => sub { 'MIDI-Drummer.mid' } );
 has bars => ( is => 'ro', default => sub { 4 } );
+has swing => ( is => 'ro', default => sub { 0 } );
 
 
 # kit
@@ -91,8 +92,11 @@ has low_floor_tom => ( is => 'ro', default => sub { 'n41' } );
 has whole => ( is => 'ro', default => sub { 'wn' } );
 has half => ( is => 'ro', default => sub { 'hn' } );
 has quarter => ( is => 'ro', default => sub { 'qn' } );
+has triplet_quarter => ( is => 'ro', default => sub { 'tqn' } );
 has eighth => ( is => 'ro', default => sub { 'en' } );
+has triplet_eighth => ( is => 'ro', default => sub { 'ten' } );
 has sixteenth => ( is => 'ro', default => sub { 'sn' } );
+has triplet_sixteenth => ( is => 'ro', default => sub { 'tsn' } );
 
 
 sub note { return shift->score->n(@_) }
@@ -105,7 +109,13 @@ sub count_in {
     my $self = shift;
     my $bars = shift || 1;
     for my $i ( 1 .. $self->beats * $bars) {
-        $self->note( $self->quarter, $self->closed_hh );
+        if ( $self->swing )
+        {
+            $self->note( $self->triplet_quarter, $self->closed_hh );
+        }
+        else {
+            $self->note( $self->quarter, $self->closed_hh );
+        }
     }
 }
 
@@ -117,10 +127,22 @@ sub metronome {
     for my $n ( 1 .. $self->beats * $bars ) {
         if ( $self->beats % 3 == 0 )
         {
-            $self->note( $self->quarter, $self->open_hh, $n % 3 ? $self->kick : $self->snare );
+            if ( $self->swing )
+            {
+                $self->note( $self->triplet_quarter, $self->open_hh, $n % 3 ? $self->kick : $self->snare );
+            }
+            else {
+                $self->note( $self->quarter, $self->open_hh, $n % 3 ? $self->kick : $self->snare );
+            }
         }
         else {
-            $self->note( $self->quarter, $self->open_hh, $n % 2 ? $self->kick : $self->snare );
+            if ( $self->swing )
+            {
+                $self->note( $self->triplet_quarter, $self->open_hh, $n % 2 ? $self->kick : $self->snare );
+            }
+            else {
+                $self->note( $self->quarter, $self->open_hh, $n % 2 ? $self->kick : $self->snare );
+            }
         }
     }
 }
@@ -145,7 +167,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -156,10 +178,11 @@ version 0.03
     signature => '3/4',
     bars => 32,
     patch => 26, # TR808
+    swing => 1,
  );
  $d->count_in();
  $d->note( $d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare )
-    for 1 .. $d->beats * $d->bars;  # Alternate even beats
+    for 1 .. $d->beats * $d->bars;  # Alternate beats
  $d->metronome();  # <- Similar but honoring time signature
  $d->write();
 
@@ -180,6 +203,8 @@ MIDI score.
 
 =head2 patch: 0
 
+=head2 swing: 0
+
 =head2 bpm: 120
 
 =head2 reverb: 0
